﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns="http://www.w3.org/1999/xhtml"
							  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
							  xmlns:msa="http://www.publictalksoftware.co.uk/msa">
	<!-- Output specification -->
	<xsl:output method="html" indent="yes" version="4.01"
	  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

	<!-- Parameters -->
	<xsl:param name="CSSFile1"></xsl:param>

	<xsl:variable name="EventsDatabase" select="document('MSA_SpecialEventsDatabase.xml')"/>
				  
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<xsl:choose>
				<xsl:when test="//Settings/ForeignGroupMode=1">
					<xsl:attribute name="lang">
						<xsl:value-of select="//Settings/ForeignGroupLanguageCode"/>
					</xsl:attribute>
					<xsl:attribute name="dir">
						<xsl:value-of select="//Settings/ForeignGroupDirection"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="lang">
						<xsl:value-of select="//Settings/LanguageCode"/>
					</xsl:attribute>
					<xsl:attribute name="dir">
						<xsl:value-of select="//Settings/Direction"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<head>
				<meta http-equiv="X-UA-Compatible" content="IE=edge" />
				<meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
				<xsl:choose>
					<xsl:when test="$CSSFile1 !=''">
						<style type="text/css">
							<xsl:value-of select="$CSSFile1"/>
						</style>
					</xsl:when>
					<xsl:otherwise>
						<link rel="stylesheet" type="text/css" href="Workbook-S-140-Grid.css"/>
					</xsl:otherwise>
				</xsl:choose>
				<title>
					<xsl:value-of select="//Labels/Congregation"/>&#160;<xsl:value-of select="//Labels/Title" />
				</title>
			</head>
			<body>
				<table class="styled-table">
					<thead>
						<td>
							<xsl:text>Date</xsl:text>
						</td>
						<td>
							<xsl:text>Chairman</xsl:text>
						</td>
						<td>
							<xsl:text>Counsellor</xsl:text>
						</td>
						<td>
							<xsl:text>Prayer Open</xsl:text>
						</td>
						<td>
							<xsl:text>Treasures</xsl:text>
						</td>
						<td>
							<xsl:text>Gems</xsl:text>
						</td>
						<td>
							<xsl:text>Discussion 1</xsl:text>
						</td>
						<td>
							<xsl:text>Discussion 2</xsl:text>
						</td>
						<td>
							<xsl:text>Living 1</xsl:text>
						</td>
						<td>
							<xsl:text>Living 2</xsl:text>
						</td>
						<td>
							<xsl:text>Living 3</xsl:text>
						</td>
						<td>
							<xsl:text>CBS Conductor</xsl:text>
						</td>
						<td>
							<xsl:text>CBS Reader</xsl:text>
						</td>
						<td>
							<xsl:text>Prayer Close</xsl:text>
						</td>
					</thead>
						<xsl:for-each select="MeetingWorkBook/Meeting">
						<tr>
							<!-- Search for Special Event -->
							<!-- Still need to handle FLG mode-->
							<xsl:variable name="event" select="$EventsDatabase/msa:SpecialEvents/msa:SpecialEvent[@Week = current()/Date/@ThisWeek]"/>

							<xsl:choose>
								
								<!-- Special Event -->
								<xsl:when test="$event">
									<xsl:choose>

										<!-- Simple Special Event -->
										<xsl:when test="$event/msa:MWBEventType = 'MWBSpecialEvent'">
											<!-- Event -->
											<xsl:apply-templates select="$event"/>
										</xsl:when>

										<!-- Memorial -->
										<xsl:when test="$event/msa:MWBEventType = 'MWBMemorial'">
											<xsl:if test="$event/msa:DateTime/msa:Date/@WeekendEvent='true'">
												<!-- Midweek Meeting -->
												<xsl:apply-templates select="."/>
											</xsl:if>
										</xsl:when>

										<xsl:when test="$event/msa:MWBEventType = 'MWBVideoconferenceConvention'">
											<!-- Midweek Meeting -->
											<xsl:apply-templates select="."/>
										</xsl:when>

										<!-- Circuit Overseer Visit -->
										<xsl:when test="$event/msa:MWBEventType = 'MWBCircuitOverseerMeeting'">
											<!-- Midweek Meeting -->
											<xsl:apply-templates select="."/>
										</xsl:when>

										<!-- Normal Week -->
										<xsl:otherwise>
											<!-- Midweek Meeting -->
											<xsl:apply-templates select="."/>
										</xsl:otherwise>

									</xsl:choose>
								</xsl:when>
								
								<!-- Normal Week -->
								<xsl:otherwise>
									<!-- Midweek Meeting -->
									<xsl:apply-templates select="."/>
								</xsl:otherwise>
								
							</xsl:choose>
						</tr>
					</xsl:for-each>
					</table>
			</body>
		</html>
	</xsl:template>

	<!-- Midweek Meeting -->
	<xsl:template match="Meeting">
		<td>
			<xsl:value-of select="MeetingDate/@Day"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="MeetingDate/@Month"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="MeetingDate/@Year"/>
		</td>
		<td>
			<xsl:value-of select="Chairman"/>
		</td>
		<td>
			<xsl:value-of select="AuxCounsellor1"/>
		</td>
		<td>
			<xsl:value-of select="PrayerOpen"/>
		</td>
		<td>
			<xsl:value-of select="TFGW/TFGWItem[1]/Name"/>
		</td>
		<td>
			<xsl:value-of select="TFGW/TFGWItem[2]/Name"/>
		</td>
		<td>
			<xsl:choose>
				<xsl:when test="AYFM/Teaching[1]/Names/Name[1]">
					<xsl:value-of select="AYFM/Teaching[1]/Names/Name[1]"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- Empty cell if Name does not exist -->
				</xsl:otherwise>
			</xsl:choose>
		</td>
		<td>
			<xsl:choose>
				<xsl:when test="AYFM/Teaching[2]/Names/Name[1]">
					<xsl:value-of select="AYFM/Teaching[2]/Names/Name[1]"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- Empty cell if Name does not exist -->
				</xsl:otherwise>
			</xsl:choose>
		</td>
		<td>
			<xsl:choose>
				<xsl:when test="LAC/LACItem[1]/Name">
					<xsl:value-of select="LAC/LACItem[1]/Name"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- Empty cell if Name does not exist -->
				</xsl:otherwise>
			</xsl:choose>
		</td>
		<td>
			<xsl:choose>
				<xsl:when test="LAC/LACItem[2]/Name">
					<xsl:value-of select="LAC/LACItem[2]/Name"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- Empty cell if Name does not exist -->
				</xsl:otherwise>
			</xsl:choose>
		</td>
		<td>
			<xsl:choose>
				<xsl:when test="LAC/LACItem[3]/Name">
					<xsl:value-of select="LAC/LACItem[3]/Name"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- Empty cell if Name does not exist -->
				</xsl:otherwise>
			</xsl:choose>
		</td>
		<td>
			<xsl:value-of select="LAC/CongregationBibleStudy/Conductor"/>
		</td>
		<td>
			<xsl:value-of select="LAC/CongregationBibleStudy/Reader"/>
		</td>
		<td>
			<xsl:value-of select="LAC/PrayerEnd"/>
		</td>
	</xsl:template>

	<!-- Simple Special Event -->
	<xsl:template match="msa:SpecialEvent">
		<tr>
			<td>
				<xsl:value-of select="msa:DateTime/msa:Date"/>
			</td>
			<td colspan="13">
				<xsl:value-of select="msa:Event"/>
			</td>
		</tr>
	</xsl:template>

</xsl:stylesheet>